#[repr(transparent)]pub struct Mask(pub u32);Expand description
Mask register for all port GPIO pins
Tuple Fields
0: u32Implementations
Sourceimpl Mask
impl Mask
Sourcepub const fn maskp(&self) -> u32
pub const fn maskp(&self) -> u32
Controls which bits corresponding to PIOm_n are active in the MPORT register (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package.0 = Read MPORT: pin state; write MPORT: load output bit. 1 = Read MPORT: 0; write MPORT: output bit not affected.
Sourcepub const fn set_maskp(&mut self, val: u32)
pub const fn set_maskp(&mut self, val: u32)
Controls which bits corresponding to PIOm_n are active in the MPORT register (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package.0 = Read MPORT: pin state; write MPORT: load output bit. 1 = Read MPORT: 0; write MPORT: output bit not affected.