#[repr(transparent)]pub struct Mpin(pub u32);Expand description
Masked port register for all port GPIO pins
Tuple Fields
0: u32Implementations
Sourceimpl Mpin
impl Mpin
Sourcepub const fn mportp(&self) -> u32
pub const fn mportp(&self) -> u32
Masked port register (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = Read: pin is LOW and/or the corresponding bit in the MASK register is 1; write: clear output bit if the corresponding bit in the MASK register is 0. 1 = Read: pin is HIGH and the corresponding bit in the MASK register is 0; write: set output bit if the corresponding bit in the MASK register is 0.
Sourcepub const fn set_mportp(&mut self, val: u32)
pub const fn set_mportp(&mut self, val: u32)
Masked port register (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = Read: pin is LOW and/or the corresponding bit in the MASK register is 1; write: clear output bit if the corresponding bit in the MASK register is 0. 1 = Read: pin is HIGH and the corresponding bit in the MASK register is 0; write: set output bit if the corresponding bit in the MASK register is 0.